@@ -1,8 +1,5 @@
 package Courriel;
-{
-  $Courriel::VERSION = '0.30';
-}
-
+$Courriel::VERSION = '0.32';
 use 5.10.0;
 
 use strict;
@@ -398,7 +395,7 @@ sub _parse {
     my $class     = shift;
     my $text      = shift;
 
-    my ( $line_sep, $sep_idx, $headers ) = $class->_parse_headers($text);
+    my ( $sep_idx, $headers ) = $class->_parse_headers($text);
 
     substr( ${$text}, 0, $sep_idx ) = q{};
 
@@ -411,7 +408,6 @@ sub _parse_headers {
 
     my $header_text;
     my $sep_idx;
-    my $line_sep;
 
     # We want to ignore mbox message separators - this is a pretty lax parser,
     # but we may find broken lines. The key is that it starts with From
@@ -423,20 +419,16 @@ sub _parse_headers {
     if ( ${$text} =~ /^(.+?)($Courriel::Helpers::LINE_SEP_RE)\g{2}/s ) {
         $header_text = $1 . $2;
         $sep_idx     = ( length $header_text ) + ( length $2 );
-        $line_sep    = $2;
     }
     else {
-        return ( q{}, 0, Courriel::Headers::->new() );
+        return ( 0, Courriel::Headers::->new() );
     }
 
-    # Need to quote class name or else this perl sees this as
-    # Courriel::Headers() because of the Headers type constraint.
     my $headers = Courriel::Headers::->parse(
-        text     => \$header_text,
-        line_sep => $line_sep,
+        text => \$header_text,
     );
 
-    return ( $line_sep, $sep_idx, $headers );
+    return ( $sep_idx, $headers );
 }
 
 {
@@ -523,7 +515,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: High level email parsing and manipulation
 
-
+__END__
 
 =pod
 
@@ -533,7 +525,7 @@ Courriel - High level email parsing and manipulation
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -551,9 +543,6 @@ version 0.30
 
 =head1 DESCRIPTION
 
-B<This software is still very alpha, and the API may change without warning in
-future versions.>
-
 This class exists to provide a high level API for working with emails,
 particular for processing incoming email. It is primarily a wrapper around the
 other classes in the Courriel distro, especially L<Courriel::Headers>,
@@ -561,6 +550,8 @@ L<Courriel::Part::Single>, and L<Courriel::Part::Multipart>. If you need lower
 level information about an email, it should be available from one of these
 classes.
 
+=encoding utf-8
+
 =head1 API
 
 This class provides the following methods:
@@ -769,20 +760,44 @@ better than the ones mentioned above.
 This module rips some chunks of code from a few other places, notably several
 of the Email suite modules.
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-courriel@rt.cpan.org>, or
+through the web interface at L<http://rt.cpan.org>.  I will be notified, and
+then you'll automatically be notified of progress on your bug as I make
+changes.
+
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
+
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time, which seems unlikely at best.
+
+To donate, log into PayPal and send money to autarch@urth.org or use the
+button on this page: L<http://www.urth.org/~autarch/fs-donation.html>
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
