@@ -1,8 +1,5 @@
 package Courriel::Builder;
-{
-  $Courriel::Builder::VERSION = '0.30';
-}
-
+$Courriel::Builder::VERSION = '0.32';
 use strict;
 use warnings;
 
@@ -447,7 +444,7 @@ sub _attachment_disposition {
 
 # ABSTRACT: Build emails with sugar
 
-
+__END__
 
 =pod
 
@@ -457,7 +454,7 @@ Courriel::Builder - Build emails with sugar
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -484,6 +481,8 @@ This module provides some sugar syntax for emails of all shapes sizes, from
 simple emails with a plain text body to emails with both plain and html
 bodies, html with attached images, etc.
 
+=encoding utf-8
+
 =head1 API
 
 This module exports all of the following functions by default. It uses
@@ -662,12 +661,12 @@ This creates an email with this structure:
         html_body(
             $html_text,
             attach(
-                file => 'path/to/image1.jpg',
-                cid  => 'image1',
+                file       => 'path/to/image1.jpg',
+                content_id => 'image1',
             ),
             attach(
-                file => 'path/to/image2.jpg',
-                cid  => 'image2',
+                file       => 'path/to/image2.jpg',
+                content_id => 'image2',
             ),
         ),
     );
@@ -697,6 +696,8 @@ This creates an email with this structure:
         attach( content => \$png_image_content ),
     );
 
+This creates an email with this structure:
+
     multipart/mixed
       |
       |-- multipart/alternative
@@ -711,16 +712,16 @@ This creates an email with this structure:
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
