@@ -1,8 +1,5 @@
 package Courriel::Header;
-{
-  $Courriel::Header::VERSION = '0.30';
-}
-
+$Courriel::Header::VERSION = '0.32';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -155,7 +152,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A single header's name and value
 
-
+__END__
 
 =pod
 
@@ -165,7 +162,7 @@ Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -176,6 +173,8 @@ version 0.30
 
 This class represents a single header, which consists of a name and value.
 
+=encoding utf-8
+
 =head1 API
 
 This class supports the following methods:
@@ -218,16 +217,16 @@ This class does the C<Courriel::Role::Streams> role.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
