@@ -1,8 +1,5 @@
 package Courriel::Header::ContentType;
-{
-  $Courriel::Header::ContentType::VERSION = '0.30';
-}
-
+$Courriel::Header::ContentType::VERSION = '0.32';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -85,7 +82,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: The content type for an email part
 
-
+__END__
 
 =pod
 
@@ -95,7 +92,7 @@ Courriel::Header::ContentType - The content type for an email part
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -122,6 +119,8 @@ Here are some typical headers:
 
   Content-Type: image/jpeg; name="Filename.jpg"
 
+=encoding utf-8
+
 =head1 API
 
 This class supports the following methods:
@@ -228,16 +227,16 @@ This class does the L<Courriel::Role::HeaderWithAttributes> role.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
