@@ -1,8 +1,5 @@
 package Courriel::Header::Disposition;
-{
-  $Courriel::Header::Disposition::VERSION = '0.30';
-}
-
+$Courriel::Header::Disposition::VERSION = '0.32';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -103,7 +100,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: The content disposition for an email part
 
-
+__END__
 
 =pod
 
@@ -113,7 +110,7 @@ Courriel::Header::Disposition - The content disposition for an email part
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -146,6 +143,8 @@ Here are some typical headers:
   Content-Disposition: attachment; filename="foo-bar.jpg";
     creation-date="Tue, 31 May 2011 09:41:13 -0700"
 
+=encoding utf-8
+
 =head1 API
 
 This class supports the following methods:
@@ -257,16 +256,16 @@ This class does the L<Courriel::Role::HeaderWithAttributes> role.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
