@@ -1,8 +1,5 @@
 package Courriel::HeaderAttribute;
-{
-  $Courriel::HeaderAttribute::VERSION = '0.29';
-}
-
+$Courriel::HeaderAttribute::VERSION = '0.32';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -175,7 +172,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A single attribute belonging to a header
 
-
+__END__
 
 =pod
 
@@ -185,7 +182,7 @@ Courriel::HeaderAttribute - A single attribute belonging to a header
 
 =head1 VERSION
 
-version 0.29
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -197,6 +194,8 @@ version 0.29
 This class represents a single attribute belonging to a header. An attribute
 consists of a name and value, with optional charset and language information.
 
+=encoding utf-8
+
 =head1 API
 
 This class supports the following methods:
@@ -267,16 +266,16 @@ This class does the C<Courriel::Role::Streams> role.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
