@@ -1,8 +1,5 @@
 package Courriel::Part::Multipart;
-{
-  $Courriel::Part::Multipart::VERSION = '0.30';
-}
-
+$Courriel::Part::Multipart::VERSION = '0.32';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -111,7 +108,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A part which contains other parts
 
-
+__END__
 
 =pod
 
@@ -121,7 +118,7 @@ Courriel::Part::Multipart - A part which contains other parts
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -134,6 +131,8 @@ version 0.30
 
 This class represents a multipart email part which contains other parts.
 
+=encoding utf-8
+
 =head1 API
 
 This class provides the following methods:
@@ -243,16 +242,16 @@ roles.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
