@@ -1,8 +1,5 @@
 package Courriel::Part::Single;
-{
-  $Courriel::Part::Single::VERSION = '0.30';
-}
-
+$Courriel::Part::Single::VERSION = '0.32';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -202,7 +199,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A part which does not contain other parts, only content
 
-
+__END__
 
 =pod
 
@@ -212,7 +209,7 @@ Courriel::Part::Single - A part which does not contain other parts, only content
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -227,6 +224,8 @@ version 0.30
 This class represents a single part that does not contain other parts, just
 content.
 
+=encoding utf-8
+
 =head1 API
 
 This class provides the following methods:
@@ -367,16 +366,16 @@ roles.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
